# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!-- version list -->

## v0.10.7 (2025-11-03)

### Bug Fixes

- **cli**: Reduce function parameter count using dataclasses
  ([`e86dbee`](https://github.com/feniix/kinemotion/commit/e86dbeef6677984b0cb256158c8e5ff3ad24b5fc))


## v0.10.6 (2025-11-03)

### Bug Fixes

- **cli**: Reduce cognitive complexity in _process_single and _process_batch
  ([`42434af`](https://github.com/feniix/kinemotion/commit/42434af3716afd841c80c118b6e1122846a685ed))


## v0.10.5 (2025-11-03)

### Bug Fixes

- **kinematics**: Reduce cognitive complexity in calculate_drop_jump_metrics
  ([`d6a06f3`](https://github.com/feniix/kinemotion/commit/d6a06f3671eb370a971c73c98270668d5aefe9b1))


## v0.10.4 (2025-11-03)

### Bug Fixes

- **api**: Reduce cognitive complexity in process_video function
  ([`d2e05cb`](https://github.com/feniix/kinemotion/commit/d2e05cb415067a1a1b081216a9474ccda1ae2567))


## v0.10.3 (2025-11-03)

### Bug Fixes

- Reduce function parameter count using dataclass
  ([`0b8abfd`](https://github.com/feniix/kinemotion/commit/0b8abfd6ee53835ba3d787924747ab5e46066395))


## v0.10.2 (2025-11-03)

### Bug Fixes

- Replace legacy numpy random functions with Generator API
  ([`5cfa31b`](https://github.com/feniix/kinemotion/commit/5cfa31bce040eadfc53d52654c2e75087ef087a5))


## v0.10.1 (2025-11-03)

### Bug Fixes

- Resolve SonarCloud code quality issues
  ([`73f7784`](https://github.com/feniix/kinemotion/commit/73f778491bc01bfed973421fe5261364f8540147))

### Build System

- Add style checker for commit messages
  ([`d25669b`](https://github.com/feniix/kinemotion/commit/d25669bdf17810a38a86fbd9b03e208ea14f5326))

- Migrate from mypy to pyright for type checking
  ([`521b526`](https://github.com/feniix/kinemotion/commit/521b52619553bb5b3ee61e0db4ff6fd06744ac7a))

### Documentation

- Install precommit hook for improving markdown
  ([`546164b`](https://github.com/feniix/kinemotion/commit/546164b9f68cf3222da9753fdd2f2cd272ead90f))

- Update documentation for batch processing and Python API
  ([`f0fa8b6`](https://github.com/feniix/kinemotion/commit/f0fa8b69b927ff4a2e7f15bac242374592fe0eb9))


## v0.10.0 (2025-11-02)

### Features

- Add batch processing mode to CLI
  ([`b0ab3c6`](https://github.com/feniix/kinemotion/commit/b0ab3c6b37a013402ff7a89305a68e49549eeae3))

## v0.9.0 (2025-11-02)

### Features

- Add programmatic API for bulk video processing
  ([`213de56`](https://github.com/feniix/kinemotion/commit/213de564fda96b461807dbefa2795e037a5edc94))

## v0.8.3 (2025-11-02)

### Bug Fixes

- Create new release
  ([`5f6322b`](https://github.com/feniix/kinemotion/commit/5f6322b6da24631f95f4e3036ed145e0d47b53a1))

### Documentation

- Update repository metadata for GHCR package description
  ([`4779355`](https://github.com/feniix/kinemotion/commit/4779355901a407514d83cf2aa82f55fa083e7e63))

## v0.8.2 (2025-11-02)

### Bug Fixes

- Add OCI annotations to Docker manifest for GHCR metadata
  ([`c6e2295`](https://github.com/feniix/kinemotion/commit/c6e2295dd5eb3eae6b820d3dc7a84d730772de41))

## v0.8.1 (2025-11-02)

### Bug Fixes

- Add OCI-compliant labels to Docker image
  ([`6b18b33`](https://github.com/feniix/kinemotion/commit/6b18b33538615048c8ea572c4ebc402160ee1c5e))

## v0.8.0 (2025-11-02)

### Features

- Add Docker support and GitHub Container Registry publishing
  ([`249ca4c`](https://github.com/feniix/kinemotion/commit/249ca4c0c0ab40cda5acfebac012db8075b9694f))

## v0.7.1 (2025-11-01)

### Bug Fixes

- Update documentation for auto-tuning system
  ([`6c1a135`](https://github.com/feniix/kinemotion/commit/6c1a135acf5cce7a627644dbc6393460277906ad))

## v0.7.0 (2025-11-01)

### Features

- Add intelligent auto-tuning and video rotation handling
  ([`7b35f67`](https://github.com/feniix/kinemotion/commit/7b35f6790dd8b6714f3e42389555107a043d486c))

## v0.6.4 (2025-10-26)

### Bug Fixes

- Project urls
  ([`c7b5914`](https://github.com/feniix/kinemotion/commit/c7b5914d3516e0f59dcf88ac81f99ffe94edb706))

## v0.6.3 (2025-10-26)

### Bug Fixes

- Changelog markdown
  ([`976de66`](https://github.com/feniix/kinemotion/commit/976de66b2a964b83240a559ea097cb74f5e1a537))

## v0.6.2 (2025-10-26)

### Bug Fixes

- Add semantic-release insertion flag to CHANGELOG.md
  ([`93f3a28`](https://github.com/feniix/kinemotion/commit/93f3a28c750bdb70b2a57f9b0c1910b105753980))

## \[Unreleased\]

### Added

- Your new feature here.

### Changed

- Your change here.

### Deprecated

- Your deprecated feature here.

### Removed

- Your removed feature here.

### Fixed

- Your bug fix here.

### Security

- Your security fix here.

## \[0.5.0\] - 2025-10-26

### Added

- Initial release of `kinemotion`.
